@@ -20,7 +20,8 @@ class DonorAddress(models.Model):
 
 class Donor(models.Model):
     user = models.ForeignKey(User, blank=True, null=True)
-    name = models.CharField(max_length=250)
+    first_name = models.CharField(max_length=250)
+    last_name = models.CharField(max_length=250)
     address = models.ForeignKey(DonorAddress, related_name="addresses",
             null=True, blank=True)
     mailing_address = models.ForeignKey(DonorAddress,
@@ -29,12 +30,15 @@ class Donor(models.Model):
     phone = models.CharField(max_length=10, null=True, blank=True)
 
     def save(self, **kwargs):
-        if self.user and not self.name:
-            self.name = "%s %s" % (self.user.first_name, self.user.last_name)
+        if self.user:
+            if not self.first_name:
+                self.first_name = self.user.first_name
+            if not self.last_name:
+                self.last_name = self.user.last_name
         super(Donor, self).save(**kwargs)
 
     def __unicode__(self):
-        return self.name
+        return "%s %s" % (self.first_name, self.last_name)
 
 
 class DonationType(models.Model):
@@ -50,7 +54,8 @@ class DonationTypeOption(models.Model):
     donation_type = models.ForeignKey(DonationType, related_name="options")
     amount = models.PositiveIntegerField(help_text=_(u"Amount to donate"))
     length = models.PositiveIntegerField(default=1,
-        help_text=_(u"Number of months per repeat (1 is one month, 12 is one year)")
+        help_text=_(u"Number of months per repeat "
+                u"(1 is one month, 12 is one year)")
     )
     repeat = models.PositiveIntegerField(
         default=0, null=True, blank=True,
@@ -85,7 +90,8 @@ class PromoCode(models.Model):
 
 class Donation(models.Model):
     donor = models.ForeignKey(Donor)
-    donation_type = models.ForeignKey(DonationTypeOption, null=True, blank=True)
+    donation_type = models.ForeignKey(DonationTypeOption, null=True,
+            blank=True)
     code = models.ForeignKey(PromoCode, null=True, blank=True)
     amount = models.DecimalField(max_digits=9, decimal_places=2)
     created = models.DateTimeField(auto_now_add=True)
